@@ -78,9 +78,7 @@ class Player:
         )
 
     def get_matches(self, unranked: bool = False) -> List["Match"]:
-        """
-        Return player’s matches.
-        """
+        """Return player’s matches."""
         if self.matches is None:
             res = ett_parser.get_matches(self.id, unranked)
             if not res:
@@ -130,8 +128,10 @@ class Player:
         [print_match(m) for m in self.get_matches() if m.id in m_incomplete_id_values]
 
     def get_elo_history(self) -> pd.DataFrame:
-        """
-        Returns player’s elo score history.
+        """Returns player’s elo score history.
+
+        Returns:
+            pd.DataFrame: [description]
         """
         if self.elo_history is None:
             res = ett_parser.get_elo_history(self.id)
@@ -187,6 +187,8 @@ class Match:
         self.home_score = match["home-score"]
         self.away_score = match["away-score"]
         self.elo_change = match["elo-change"]
+        self.home_elo_avg = match["home-elo-avg"]
+        self.away_elo_avg = match["away-elo-avg"]
 
         home_player_index = 0 if match["players"][0]["team"] == Player.HOME else 1
         self.home_player = Player(
@@ -201,6 +203,7 @@ class Match:
         self.rounds = [self.Round(r) for r in match["rounds"]][::-1]
 
     def print(self):
+        """Pretty-print match's information"""
         print_match(self)
 
     # Keeping inside Match for organizational / readability purposes even though it's a static method.
@@ -224,10 +227,16 @@ class ETT:
     def __init__(self):
         self.leaderboard = None
 
-    def user_search(self, username, perfect_match=False) -> List[Player]:
-        """
-        Returns a list of players whose name contains username, if perfect_match is False.
-        Otherwise, it returns a list of players whose usernames is a perfect match with username.
+    def user_search(self, username: str, perfect_match: bool = False) -> List[Player]:
+        """Returns a list of players whose name contains ``username``, if ``perfect_match`` is False.
+        Otherwise, it returns a list of players whose username is a perfect match with ``username``.
+
+        Args:
+            username (str): Username
+            perfect_match (bool, optional): Whether to perform perfect match in string matching. Defaults to False.
+
+        Returns:
+            List[Player]: List of players whose names match with `username`.
         """
         res = ett_parser.user_search(username)
 
@@ -250,9 +259,15 @@ class ETT:
     def user_search_dataframe(
         self, username: str, perfect_match: bool = False
     ) -> pd.DataFrame:
-        """
-        Returns a list of players whose name contains username, if perfect_match is False.
+        """Returns a list of players whose name contains username, if perfect_match is False.
         Otherwise, it returns a list of players whose usernames is a perfect match with username.
+
+        Args:
+            username (str): Username
+            perfect_match (bool, optional): Whether to perform perfect match in string matching. Defaults to False.
+
+        Returns:
+            pd.DataFrame: A dataframe of players whose names match with `username`.
         """
         return pd.DataFrame(
             [
@@ -262,9 +277,14 @@ class ETT:
             ]
         ).dropna(how="all", axis="columns")
 
-    def get_leaderboard(self, num_players=10) -> List[Player]:
-        """
-        Returns a list of players from the leaderboard.
+    def get_leaderboard(self, num_players: int = 10) -> List[Player]:
+        """Returns a list of players from the leaderboard.
+
+        Args:
+            num_players (int, optional): Max number of players to return. Defaults to 10.
+
+        Returns:
+            List[Player]: Top players in ETT's leaderboard.
         """
         if self.leaderboard is None:
             res = ett_parser.get_leaderboard(num_players)
@@ -277,8 +297,13 @@ class ETT:
         return self.leaderboard
 
     def get_leaderboard_dataframe(self, num_players: int = 10) -> pd.DataFrame:
-        """
-        Returns a pandas dataframe with players from the leaderboard.
+        """Returns a pandas dataframe with players from the leaderboard.
+
+        Args:
+            num_players (int, optional): Max number of players to return. Defaults to 10.
+
+        Returns:
+            pd.DataFrame: Top players in ETT's leaderboard.
         """
         lb = pd.DataFrame(
             [vars(u) for u in self.get_leaderboard(num_players) if u is not None]
@@ -325,7 +350,9 @@ class Cohort:
             cohort_elo,
         ).ffill(axis=0)
 
-    def get_matches(self, unranked: bool = False) -> List["Match"]:
+    def get_matches(
+        self, unranked: bool = False
+    ) -> List["Match"]:  # TODO: filter unranked
         """
         Returns matches among players in the cohort
         """
@@ -394,12 +421,21 @@ class Cohort:
                 ("losses" + ranked_label): losses,
                 ("win_rate" + ranked_label): win_rate,
             }
-            return pd.DataFrame(frame).reset_index()
+
+            df_matches_stats = pd.DataFrame(frame)
+
+            if df_matches_stats.empty:
+                df_matches_stats = pd.DataFrame(
+                    0, index=self.players, columns=list(frame.keys())
+                )
+
+            return df_matches_stats.reset_index()
 
         ranked_stats = matches_stats(matches, ranked=True)
         all_stats = matches_stats(matches, ranked=False)
+
         cohort_stats = (
-            ranked_stats.merge(all_stats)
+            all_stats.merge(ranked_stats)
             .round(0)
             .sort_values(by=["win_rate_ranked"], ascending=False)
         )
@@ -494,9 +530,11 @@ class Tournament:
 
 
 def official_tournament_leaderboard_dataframe() -> pd.DataFrame:
-    """
-    Returns a pandas dataframe with the leaderboard of the Eleven official tournaments
+    """Returns a pandas dataframe with the leaderboard of the Eleven official tournaments
     available at http://lavadesignstudio.co.uk/eleven-rankings/.
+
+    Returns:
+        pd.DataFrame: A dataframe with the leaderboard of Eleven official tournaments.
     """
     return ett_parser.get_leaderboard_official_tournament()[0]
 
@@ -506,7 +544,7 @@ def print_match(match: Match):
 
     Args:
         match (Match): A match.
-    """    
+    """
     print(f"Match #{match.id} : {match.created_at}\n")
     home_elo_sign = (-1) ** match.winning_team
     df = pd.DataFrame(
